@@ -9,7 +9,7 @@ from scipy import special, spatial
 import numpy as np
 from .independence_tests_base import CondIndTest
 from numba import jit
-
+import warnings
 
 class CMIknn(CondIndTest):
     r"""Conditional mutual information test based on nearest-neighbor estimator.
@@ -162,12 +162,17 @@ class CMIknn(CondIndTest):
             # Standardize
             array = array.astype(np.float64)
             array -= array.mean(axis=1).reshape(dim, 1)
-            array /= array.std(axis=1).reshape(dim, 1)
+            std = array.std(axis=1)
+            for i in range(dim):
+                if std[i] != 0.:
+                    array[i] /= std[i]
+            # array /= array.std(axis=1).reshape(dim, 1)
             # FIXME: If the time series is constant, return nan rather than
             # raising Exception
-            if np.isnan(array).sum() != 0:
-                raise ValueError("nans after standardizing, "
-                                 "possibly constant array!")
+            if np.any(std == 0.):
+                warnings.warn("Possibly constant array!")
+                # raise ValueError("nans after standardizing, "
+                #                  "possibly constant array!")
         elif self.transform == 'uniform':
             array = self._trafo2uniform(array)
         elif self.transform == 'ranks':
@@ -376,12 +381,18 @@ class CMIknn(CondIndTest):
             # Standardize
             array = array.astype(np.float64)
             array -= array.mean(axis=1).reshape(dim, 1)
-            array /= array.std(axis=1).reshape(dim, 1)
+            std = array.std(axis=1)
+            for i in range(dim):
+                if std[i] != 0.:
+                    array[i] /= std[i]
+            # array /= array.std(axis=1).reshape(dim, 1)
             # FIXME: If the time series is constant, return nan rather than
             # raising Exception
-            if np.isnan(array).sum() != 0:
-                raise ValueError("nans after standardizing, "
-                                 "possibly constant array!")
+            if np.any(std == 0.):
+                warnings.warn("Possibly constant array!")
+            # if np.isnan(array).sum() != 0:
+            #     raise ValueError("nans after standardizing, "
+            #                      "possibly constant array!")
         elif self.transform == 'uniform':
             array = self._trafo2uniform(array)
         elif self.transform == 'ranks':
